@@ -4,6 +4,11 @@ import os
 import stretch_body.hello_utils as hu
 hu.print_stretch_re_use()
 
+import argparse
+parser=argparse.ArgumentParser(description='Test the audio system')
+args=parser.parse_args()
+
+
 os.system('pactl set-default-sink alsa_output.pci-0000_00_1f.3.analog-stereo')
 os.system('amixer set Master 80%')
 os.system('paplay --device=alsa_output.pci-0000_00_1f.3.analog-stereo /usr/share/sounds/ubuntu/stereo/desktop-login.ogg')
