@@ -7,6 +7,7 @@ import subprocess
 from colorama import Fore, Back, Style
 import argparse
 import stretch_body.hello_utils as hu
+from stretch_body.dynamixel_XL430 import *
 hu.print_stretch_re_use()
 
 
@@ -58,10 +59,10 @@ if robot_devices['hello-pimu']:
     val_in_range('Voltage',p.status['voltage'], vmin=p.config['low_voltage_alert'], vmax=14.5)
     val_in_range('Current',p.status['current'], vmin=0.5, vmax=p.config['high_current_alert'])
     val_in_range('Temperature',p.status['temp'], vmin=10, vmax=40)
-    val_in_range('Cliff-0',p.status['cliff_range'][0], vmin=p.config['cliff_thresh'], vmax=20)
-    val_in_range('Cliff-1',p.status['cliff_range'][1], vmin=p.config['cliff_thresh'], vmax=20)
-    val_in_range('Cliff-2',p.status['cliff_range'][2], vmin=p.config['cliff_thresh'], vmax=20)
-    val_in_range('Cliff-3',p.status['cliff_range'][3], vmin=p.config['cliff_thresh'], vmax=20)
+    val_in_range('Cliff-0',p.status['cliff_range'][0], vmin=p.config['cliff_thresh'], vmax=60)
+    val_in_range('Cliff-1',p.status['cliff_range'][1], vmin=p.config['cliff_thresh'], vmax=60)
+    val_in_range('Cliff-2',p.status['cliff_range'][2], vmin=p.config['cliff_thresh'], vmax=60)
+    val_in_range('Cliff-3',p.status['cliff_range'][3], vmin=p.config['cliff_thresh'], vmax=60)
     val_in_range('IMU AZ',p.status['imu']['az'], vmin=-10.1, vmax=-9.5)
     val_in_range('IMU Pitch', hu.rad_to_deg(p.status['imu']['pitch']), vmin=-12, vmax=12)
     val_in_range('IMU Roll', hu.rad_to_deg(p.status['imu']['roll']), vmin=-12, vmax=12)
@@ -85,20 +86,22 @@ if robot_devices['hello-dynamixel-wrist']:
             else:
                 print(Fore.RED + '[Fail] Ping of: ' + mk)
             print(Style.RESET_ALL)
-    except IOError:
+    except(IOError, DynamixelCommError):
         print(Fore.RED + '[Fail] Startup of EndOfArm')
 # #####################################################
 print(Style.RESET_ALL)
 if robot_devices['hello-dynamixel-head']:
     print('---- Checking Head ----')
     h = r.head
-    for mk in h.motors.keys():
-        if h.motors[mk].do_ping():
-            print(Fore.GREEN +'[Pass] Ping of: '+mk)
-        else:
-            print(Fore.RED + '[Fail] Ping of: ' + mk)
-        print(Style.RESET_ALL)
-
+    try:
+        for mk in h.motors.keys():
+            if h.motors[mk].do_ping():
+                print(Fore.GREEN +'[Pass] Ping of: '+mk)
+            else:
+                print(Fore.RED + '[Fail] Ping of: ' + mk)
+            print(Style.RESET_ALL)
+    except(IOError, DynamixelCommError):
+        print(Fore.RED + '[Fail] Startup of EndOfArm')
 # #####################################################
 print(Style.RESET_ALL)
 if robot_devices['hello-wacc']:
